@@ -1,6 +1,6 @@
 package Search::Tools::HiLiter;
 
-use 5.008;
+use 5.008_003;
 use strict;
 use warnings;
 use Carp;
@@ -8,7 +8,7 @@ use Search::Tools::RegExp;
 
 use base qw( Class::Accessor::Fast );
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 sub new
 {
