@@ -1,6 +1,6 @@
 package Search::Tools::SpellCheck;
 
-use 5.008;
+use 5.008_003;
 use strict;
 use warnings;
 
@@ -8,7 +8,7 @@ use Carp;
 use base qw( Class::Accessor::Fast );
 use Text::Aspell;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 sub new
 {
